from setuptools import setup, find_packages

setup(
    name='langchain-mane',
    version='0.0.1',
    description='PYPI tutorial package creation written by TeddyNote',
    author='mane5880',
    author_email='gjtjqkr5880@gmail.com',
    url='https://github.com/teddylee777/teddynote',
    install_requires=[],
    packages=find_packages(exclude=[]),
    keywords=['langchain', 'mane', 'python langchain', 'langchain util'],
    python_requires='>=3.8',
    package_data={},
    zip_safe=False,
)